@@ -134,7 +134,9 @@ class BrailleGenerator(generator.Generator):
         role = args.get('role', obj.getRole())
         verbosityLevel = _settingsManager.getSetting('brailleVerbosityLevel')
 
-        doNotPresent = [pyatspi.ROLE_UNKNOWN]
+        doNotPresent = [pyatspi.ROLE_UNKNOWN,
+                        pyatspi.ROLE_FILLER,
+                        pyatspi.ROLE_EXTENDED]
 
         # egg-list-box, e.g. privacy panel in gnome-control-center
         if obj.parent and obj.parent.getRole() == pyatspi.ROLE_LIST_BOX:
@@ -143,10 +145,8 @@ class BrailleGenerator(generator.Generator):
         if verbosityLevel == settings.VERBOSITY_LEVEL_BRIEF:
             doNotPresent.extend([pyatspi.ROLE_ICON, pyatspi.ROLE_CANVAS])
 
-        if (role in _settingsManager.getSetting('brailleForceRoles'))\
-           or (verbosityLevel == settings.VERBOSITY_LEVEL_VERBOSE\
-               and not args.get('readingRow', False)\
-               and role not in doNotPresent):
+        if verbosityLevel == settings.VERBOSITY_LEVEL_VERBOSE \
+           and not args.get('readingRow', False) and role not in doNotPresent:
             result.append(self.getLocalizedRoleName(obj, role))
         return result
 
@@ -181,6 +181,15 @@ class BrailleGenerator(generator.Generator):
 
         return Atk.role_get_localized_name(atkRole)
 
+    def _generateUnrelatedLabels(self, obj, **args):
+        result = []
+        labels = self._script.utilities.unrelatedLabels(obj)
+        for label in labels:
+            name = self._generateName(label, **args)
+            result.extend(name)
+
+        return result
+
     #####################################################################
     #                                                                   #
     # Keyboard shortcut information                                     #
