@@ -29,8 +29,8 @@ import copy
 
 import pyatspi
 
-from . import settings
 from . import object_properties
+from . import settings
 
 # pylint: disable-msg=C0301
 
@@ -66,7 +66,7 @@ formatting = {
             'groupindex': object_properties.GROUP_INDEX_SPEECH,
         },
         'braille': {
-            'eol': settings.brailleEOLIndicator,
+            'eol': object_properties.EOL_INDICATOR_BRAILLE,
             'required': object_properties.STATE_REQUIRED_BRAILLE,
             'readonly': object_properties.STATE_READ_ONLY_BRAILLE,
             'insensitive': object_properties.STATE_INSENSITIVE_BRAILLE,
@@ -136,6 +136,11 @@ formatting = {
             'unfocused': 'label + name + roleName + positionInList + ' + MNEMONIC + ' + accelerator',
             'basicWhereAmI': 'label + roleName + name + positionInList + ' + MNEMONIC + ' + accelerator'
             },
+        pyatspi.ROLE_DIAL: {
+            'focused': 'value',
+            'unfocused': 'labelOrName + roleName + value + required + availability + ' + MNEMONIC,
+            'basicWhereAmI': 'labelOrName + roleName + value + percentage + ' + MNEMONIC + ' + accelerator + required'
+            },
         pyatspi.ROLE_DIALOG: {
             'unfocused': 'labelAndName + unrelatedLabels'
             },
@@ -257,6 +262,11 @@ formatting = {
             'unfocused': 'labelAndName + radioState + roleName + availability + ' + MNEMONIC + ' + accelerator + positionInList',
             'basicWhereAmI': 'ancestors + labelAndName + roleName + radioState + accelerator + positionInList + ' + MNEMONIC
             },
+        pyatspi.ROLE_SCROLL_BAR: {
+            'focused': 'value',
+            'unfocused': 'labelOrName + roleName + value + required + availability + ' + MNEMONIC,
+            'basicWhereAmI': 'labelOrName + roleName + value + percentage + ' + MNEMONIC + ' + accelerator + required'
+            },
         pyatspi.ROLE_SECTION: {
             'basicWhereAmI': 'label + readOnly + textRole + textContent + anyTextSelection + ' + MNEMONIC,
             'detailedWhereAmI': 'label + readOnly + textRole + textContentWithAttributes + anyTextSelection + ' + MNEMONIC + ' + ' + TUTORIAL
@@ -404,7 +414,10 @@ formatting = {
                           + [Region(" " + asString(roleName))]'
             },
         #pyatspi.ROLE_DESKTOP_ICON: 'default'
-        #pyatspi.ROLE_DIAL: 'default'
+        pyatspi.ROLE_DIAL: {
+            'unfocused': '[Component(obj,\
+                                     asString(labelOrName + value + roleName + required))]'
+            },
         #pyatspi.ROLE_DIALOG: 'default'
         #pyatspi.ROLE_DIRECTORY_PANE: 'default'
         pyatspi.ROLE_EMBEDDED: {
@@ -435,9 +448,7 @@ formatting = {
                                      asString(labelAndName + value + roleName + required))]',
             },
         pyatspi.ROLE_LABEL: {
-            'unfocused': '[Text(obj,\
-                                asString(label),\
-                                asString(eol))]'
+            'unfocused': '[Text(obj, asString(label))]'
             },
         pyatspi.ROLE_LINK: {
             'unfocused': '[Link(obj, asString(currentLineText)\
@@ -511,7 +522,10 @@ formatting = {
                                      indicator=asString(radioState))]'
             },
         #pyatspi.ROLE_ROW_HEADER: 'default'
-        #pyatspi.ROLE_SCROLL_BAR: 'default'
+        pyatspi.ROLE_SCROLL_BAR: {
+            'unfocused': '[Component(obj,\
+                                     asString(labelOrName + value + roleName + required))]'
+            },
         pyatspi.ROLE_SCROLL_PANE: {
             'unfocused': 'asPageTabOrScrollPane'
             },
