@@ -34,6 +34,7 @@ import pyatspi
 from . import braille
 from . import debug
 from . import messages
+from . import object_properties
 from . import settings
 
 from .orca_i18n import _         # for gettext support
@@ -450,8 +451,7 @@ class Generator:
         if not args.get('mode', None):
             args['mode'] = self._mode
         args['stringType'] = 'readonly'
-        if settings.presentReadOnlyText \
-           and self._script.utilities.isReadOnlyTextArea(obj):
+        if self._script.utilities.isReadOnlyTextArea(obj):
             result.append(self._script.formatting.getString(**args))
         return result
 
@@ -491,10 +491,10 @@ class Generator:
         args['stringType'] = 'checkbox'
         indicators = self._script.formatting.getString(**args)
         state = obj.getState()
-        if state.contains(pyatspi.STATE_INDETERMINATE):
-            result.append(indicators[2])
-        elif state.contains(pyatspi.STATE_CHECKED):
+        if state.contains(pyatspi.STATE_CHECKED):
             result.append(indicators[1])
+        elif state.contains(pyatspi.STATE_INDETERMINATE):
+            result.append(indicators[2])
         else:
             result.append(indicators[0])
         return result
@@ -520,6 +520,7 @@ class Generator:
     def _generateChildWidget(self, obj, **args):
         widgetRoles = [pyatspi.ROLE_CHECK_BOX,
                        pyatspi.ROLE_COMBO_BOX,
+                       pyatspi.ROLE_PUSH_BUTTON,
                        pyatspi.ROLE_RADIO_BUTTON,
                        pyatspi.ROLE_SLIDER,
                        pyatspi.ROLE_TOGGLE_BUTTON]
@@ -913,7 +914,7 @@ class Generator:
                         cellResult = self._generateRealTableCell(cell, **args)
                         if cellResult and result and self._mode == 'braille':
                             result.append(braille.Region(
-                                    settings.brailleTableCellDelimiter))
+                                object_properties.TABLE_CELL_DELIMITER_BRAILLE))
                         result.extend(cellResult)
             else:
                 result.extend(self._generateRealTableCell(obj, **args))
