@@ -56,15 +56,12 @@ class ScriptManager:
              'Miramar':          'Thunderbird',
              'Shredder':         'Thunderbird',
              'Earlybird':        'Thunderbird',
-             'bug-buddy':        'gnome_segv2',
              'gaim':             'pidgin',
              'empathy-chat':     'empathy',
              'gnome-calculator': 'gcalctool',
              'Nereid':           'Banshee',
-             'vte':              'gnome-terminal'}
-        self._toolkitNames = \
-            {'gtk':              'GAIL',
-             'clutter':          'CALLY'}
+             'vte':              'gnome-terminal',
+             'gnome-terminal-server': 'gnome-terminal'}
 
         self.setActiveScript(None, "__init__")
         debug.println(debug.LEVEL_FINEST, 'INFO: Script manager initialized')
@@ -73,15 +70,18 @@ class ScriptManager:
         """Called when this script manager is activated."""
 
         debug.println(debug.LEVEL_FINEST, 'INFO: Activating script manager')
-        self._defaultScript  = None
-        self.setActiveScript(self.getScript(None), "activate")
+        self._defaultScript = self.getScript(None)
+        self._defaultScript.registerEventListeners()
+        self.setActiveScript(self._defaultScript, "activate")
         debug.println(debug.LEVEL_FINEST, 'INFO: Script manager activated')
 
     def deactivate(self):
         """Called when this script manager is deactivated."""
 
         debug.println(debug.LEVEL_FINEST, 'INFO: Dectivating script manager')
-        self._defaultScript  = None
+        if self._defaultScript:
+            self._defaultScript.deregisterEventListeners()
+        self._defaultScript = None
         self.setActiveScript(None, "deactivate")
         self.appScripts = {}
         self.toolkitScripts = {}
@@ -142,14 +142,6 @@ class ScriptManager:
         if not (app and name):
             return None
 
-        altNames = list(self._toolkitNames.keys())
-        names = [n for n in altNames if n.lower() == name.lower()]
-        if names:
-            newName = self._toolkitNames.get(names[0])
-            debug.println(debug.LEVEL_FINEST,
-                          "mapped %s to %s" % (name, newName))
-            name = newName
-
         script = None
         for package in self._scriptPackages:
             moduleName = '.'.join((package, name))
@@ -212,7 +204,6 @@ class ScriptManager:
 
         from .scripts import default
         script = default.Script(app)
-        script.registerEventListeners()
 
         if not app:
             self._defaultScript = script
@@ -239,7 +230,6 @@ class ScriptManager:
             if not toolkitScript:
                 toolkitScript = self._createScript(app, obj)
                 toolkitScripts[objToolkit] = toolkitScript
-                toolkitScript.registerEventListeners()
             self.toolkitScripts[app] = toolkitScripts
 
         try:
@@ -250,7 +240,6 @@ class ScriptManager:
             else:
                 appScript = self._createScript(app, None)
                 self.appScripts[app] = appScript
-                appScript.registerEventListeners()
         except:
             msg = "WARNING: Exception getting app script."
             debug.printException(debug.LEVEL_ALL)
@@ -303,7 +292,6 @@ class ScriptManager:
         appList = [a for a in appList if a != None and a not in desktop]
         for app in appList:
             appScript = self.appScripts.pop(app)
-            appScript.deregisterEventListeners()
             del appScript
 
             try:
@@ -312,7 +300,6 @@ class ScriptManager:
                 pass
             else:
                 for toolkitScript in list(toolkitScripts.values()):
-                    toolkitScript.deregisterEventListeners()
                     del toolkitScript
 
             del app
