@@ -36,10 +36,12 @@ import re
 from . import chnames
 from . import debug
 from . import keynames
+from . import keybindings
 from . import input_event
 from . import messages
 from . import mouse_review
 from . import orca_state
+from . import pronunciation_dict
 from . import settings
 
 #############################################################################
@@ -558,6 +560,10 @@ class Utilities:
         except (LookupError, RuntimeError):
             role = None
 
+        role = obj.getRole()
+        if role == pyatspi.ROLE_PUSH_BUTTON and obj.name:
+            return obj.name
+
         if role == pyatspi.ROLE_COMBO_BOX:
             displayedText = self._displayedTextInComboBox(obj)
             if self.DISPLAYED_TEXT not in self._script.generatorCache:
@@ -574,7 +580,7 @@ class Utilities:
         except NotImplementedError:
             pass
         else:
-            displayedText = text.getText(0, self._script.getTextEndOffset(text))
+            displayedText = text.getText(0, text.characterCount)
 
             # [[[WDW - HACK to account for things such as Gecko that want
             # to use the EMBEDDED_OBJECT_CHARACTER on a label to hold the
@@ -602,6 +608,9 @@ class Utilities:
                         break
 
         if not displayedText:
+            # TODO - JD: This should probably get nuked. But all sorts of
+            # existing code might be relying upon this bogus hack. So it
+            # will need thorough testing when removed.
             try:
                 displayedText = obj.name
             except (LookupError, RuntimeError):
@@ -747,11 +756,13 @@ class Utilities:
         if not obj:
             obj = orca_state.locusOfFocus
 
-        if obj and obj.getRole() == pyatspi.ROLE_ENTRY \
-           and obj.parent.getRole() == pyatspi.ROLE_TOOL_BAR:
-            return True
+        if not (obj and obj.getRole() == pyatspi.ROLE_ENTRY):
+            return False
 
-        return False
+        isToolbar = lambda x: x and x.getRole() == pyatspi.ROLE_TOOL_BAR
+        toolbar = pyatspi.findAncestor(obj, isToolbar)
+
+        return toolbar != None
 
     def isFunctionalDialog(self, obj):
         """Returns True if the window is a functioning as a dialog.
@@ -782,13 +793,24 @@ class Utilities:
                     layoutOnly = True
                     break
         elif role == pyatspi.ROLE_TABLE_CELL and obj.childCount:
-            layoutOnly = obj[0].getRole() == pyatspi.ROLE_TABLE_CELL
+            if obj[0].getRole() == pyatspi.ROLE_TABLE_CELL:
+                layoutOnly = True
+            elif obj.parent.getRole() == pyatspi.ROLE_TABLE:
+                layoutOnly = self.isLayoutOnly(obj.parent)
+        elif role == pyatspi.ROLE_FILLER:
+            layoutOnly = True
         elif role == pyatspi.ROLE_SCROLL_PANE:
             layoutOnly = True
+        elif role == pyatspi.ROLE_AUTOCOMPLETE:
+            layoutOnly = True
         elif role in [pyatspi.ROLE_LIST_BOX, pyatspi.ROLE_TREE_TABLE]:
             layoutOnly = False
         elif role in [pyatspi.ROLE_DIALOG, pyatspi.ROLE_WINDOW]:
             layoutOnly = False
+        elif role == pyatspi.ROLE_LIST or self.isTableRow(obj):
+            state = obj.getState()
+            layoutOnly = not (state.contains(pyatspi.STATE_FOCUSABLE) \
+                              or state.contains(pyatspi.STATE_SELECTABLE))
         else:
             if not (self.displayedText(obj) or self.displayedLabel(obj)):
                 layoutOnly = True
@@ -946,84 +968,6 @@ class Utilities:
                     if not target in allTargets:
                         allTargets.append(target)
                         label.append(target)
-
-        # [[[TODO: HACK - we've discovered oddness in hierarchies such as
-        # the gedit Edit->Preferences dialog.  In this dialog, we have
-        # labeled groupings of objects.  The grouping is done via a FILLER
-        # with two children - one child is the overall label, and the
-        # other is the container for the grouped objects.  When we detect
-        # this, we add the label to the overall context.
-        #
-        # We are also looking for objects which have a PANEL or a FILLER as
-        # parent, and its parent has more children. Through these children,
-        # a potential label with LABEL_FOR relation may exists. We want to
-        # present this label.
-        # This case can be seen in FileChooserDemo application, in Open dialog
-        # window, the line with "Look In" label, a combobox and some
-        # presentation buttons.
-        #
-        # Finally, we are searching the hierarchy of embedded components for
-        # children that are labels.]]]
-        #
-        if not len(label):
-            potentialLabels = []
-            useLabel = False
-            if (obj.getRole() == pyatspi.ROLE_EMBEDDED):
-                candidate = obj
-                while candidate.childCount:
-                    candidate = candidate[0]
-                # The parent of this object may contain labels
-                # or it may contain filler that contains labels.
-                #
-                candidate = candidate.parent
-                for child in candidate:
-                    if child.getRole() == pyatspi.ROLE_FILLER:
-                        candidate = child
-                        break
-                # If there are labels in this embedded component,
-                # they should be here.
-                #
-                for child in candidate:
-                    if child.getRole() == pyatspi.ROLE_LABEL:
-                        useLabel = True
-                        potentialLabels.append(child)
-            elif ((obj.getRole() == pyatspi.ROLE_FILLER) \
-                    or (obj.getRole() == pyatspi.ROLE_PANEL)) \
-                and (obj.childCount == 2):
-                child0, child1 = obj
-                child0_role = child0.getRole()
-                child1_role = child1.getRole()
-                if child0_role == pyatspi.ROLE_LABEL \
-                    and not self.__hasLabelForRelation(child0) \
-                    and child1_role in [pyatspi.ROLE_FILLER, \
-                                             pyatspi.ROLE_PANEL]:
-                    useLabel = True
-                    potentialLabels.append(child0)
-                elif child1_role == pyatspi.ROLE_LABEL \
-                    and not self.__hasLabelForRelation(child1) \
-                    and child0_role in [pyatspi.ROLE_FILLER, \
-                                             pyatspi.ROLE_PANEL]:
-                    useLabel = True
-                    potentialLabels.append(child1)
-            else:
-                parent = obj.parent
-                try:
-                    parentRole = parent.getRole()
-                except:
-                    parentRole = None
-                if parentRole in [pyatspi.ROLE_FILLER, pyatspi.ROLE_PANEL]:
-                    for potentialLabel in parent:
-                        try:
-                            useLabel = self.__isLabeling(potentialLabel, obj)
-                            if useLabel:
-                                potentialLabels.append(potentialLabel)
-                                break
-                        except:
-                            pass
-
-            if useLabel and len(potentialLabels):
-                label = potentialLabels
-
         return label
 
     @staticmethod
@@ -1258,7 +1202,9 @@ class Utilities:
         if not obj.parent.getRole() == pyatspi.ROLE_TABLE:
             return False
 
-        isCell = lambda x: x and x.getRole() == pyatspi.ROLE_TABLE_CELL
+        isCell = lambda x: x and x.getRole() in [pyatspi.ROLE_TABLE_CELL,
+                                                 pyatspi.ROLE_ROW_HEADER,
+                                                 pyatspi.ROLE_COLUMN_HEADER]
         cellChildren = list(filter(isCell, [x for x in obj]))
         if len(cellChildren) == obj.childCount:
             return True        
@@ -1302,7 +1248,7 @@ class Utilities:
                     except NotImplementedError:
                         continue
                     else:
-                        if text.getText(0, self._script.getTextEndOffset(text)):
+                        if text.getText(0, text.characterCount):
                             activeDescendant = child
 
         self._script.generatorCache[self.REAL_ACTIVE_DESCENDANT][obj] = \
@@ -1365,7 +1311,7 @@ class Utilities:
                     if stateset.contains(pyatspi.STATE_SHOWING) \
                        and (extents.x >= 0) and (extents.y >= 0) \
                        and (extents.width > 0) and (extents.height > 0) \
-                       and self.isVisibleRegion(
+                       and self.containsRegion(
                             extents.x, extents.y,
                             extents.width, extents.height,
                             parentExtents.x, parentExtents.y,
@@ -1452,15 +1398,18 @@ class Utilities:
         - obj: the Accessible object
         """
 
-        while obj and obj.parent and (obj != obj.parent) \
-              and (obj.parent.getRole() != pyatspi.ROLE_APPLICATION):
-            obj = obj.parent
+        if not obj:
+            return None
 
-        if obj and obj.parent and \
-           (obj.parent.getRole() == pyatspi.ROLE_APPLICATION):
-            pass
-        else:
-            obj = None
+        stopAtRoles = [pyatspi.ROLE_ALERT,
+                       pyatspi.ROLE_DIALOG,
+                       pyatspi.ROLE_FRAME,
+                       pyatspi.ROLE_WINDOW]
+
+        while obj and obj.parent \
+              and not obj.getRole() in stopAtRoles \
+              and not obj.parent.getRole() == pyatspi.ROLE_APPLICATION:
+            obj = obj.parent
 
         return obj
 
@@ -1536,6 +1485,8 @@ class Utilities:
         # Eliminate duplicates
         d = {}
         for label in labels:
+            if label.name == root.name:
+                continue
             d[label.name] = label
         labels = list(d.values())
 
@@ -1661,7 +1612,7 @@ class Utilities:
                         morePossibleSelections = True
                     else:
                         displayedText = prevObjText.getText(0,
-                            self._script.getTextEndOffset(prevObjText))
+                            prevObjText.characterCount)
                         if len(displayedText) == 0:
                             current = prevObj
                             morePossibleSelections = True
@@ -1683,7 +1634,7 @@ class Utilities:
                         morePossibleSelections = True
                     else:
                         displayedText = nextObjText.getText(0,
-                            self._script.getTextEndOffset(nextObjText))
+                            nextObjText.characterCount)
                         if len(displayedText) == 0:
                             current = nextObj
                             morePossibleSelections = True
@@ -1831,7 +1782,7 @@ class Utilities:
         else:
             otherSelected = False
             text = obj.queryText()
-            displayedText = text.getText(0, self._script.getTextEndOffset(text))
+            displayedText = text.getText(0, text.characterCount)
             if (text.caretOffset == 0) or len(displayedText) == 0:
                 current = obj
                 morePossibleSelections = True
@@ -1846,7 +1797,7 @@ class Utilities:
                                 otherSelected = True
                             else:
                                 displayedText = prevObjText.getText(0,
-                                    self._script.getTextEndOffset(prevObjText))
+                                    prevObjText.characterCount)
                                 if len(displayedText) == 0:
                                     current = prevObj
                                     morePossibleSelections = True
@@ -1865,7 +1816,7 @@ class Utilities:
                                 otherSelected = True
                             else:
                                 displayedText = nextObjText.getText(0,
-                                    self._script.getTextEndOffset(nextObjText))
+                                    nextObjText.characterCount)
                                 if len(displayedText) == 0:
                                     current = nextObj
                                     morePossibleSelections = True
@@ -2025,22 +1976,21 @@ class Utilities:
         if not orca_state.locusOfFocus or not settings.enableEchoByCharacter:
             return False
 
-        # The check here in English is something like this: "If this
-        # character echo is enabled, then character echo is likely to
-        # happen if the locus of focus is a focusable editable text
-        # area or terminal and neither of the Ctrl, Alt, or Orca
-        # modifiers are pressed.  If that's the case, then character
-        # echo will kick in for us."
-        #
-        return (self.isTextArea(orca_state.locusOfFocus)\
-                     or orca_state.locusOfFocus.getRole() \
-                        == pyatspi.ROLE_ENTRY) \
-                and (orca_state.locusOfFocus.getRole() \
-                     == pyatspi.ROLE_TERMINAL \
-                     or (not self.isReadOnlyTextArea(orca_state.locusOfFocus) \
-                         and (orca_state.locusOfFocus.getState().contains( \
-                                  pyatspi.STATE_FOCUSABLE)))) \
-                and not (event.modifiers & settings.ORCA_CTRL_MODIFIER_MASK)
+        if len(event.event_string) != 1 \
+           or event.modifiers & keybindings.ORCA_CTRL_MODIFIER_MASK:
+            return False
+
+        obj = orca_state.locusOfFocus
+        role = obj.getRole()
+        if role == pyatspi.ROLE_TERMINAL:
+            return True
+        if role == pyatspi.ROLE_PASSWORD_TEXT:
+            return False
+
+        if obj.getState().contains(pyatspi.STATE_EDITABLE):
+            return True
+
+        return False
 
     def wordAtCoords(self, acc, x, y):
         """Get the word at the given coords in the accessible.
@@ -2058,7 +2008,7 @@ class Utilities:
         except NotImplementedError:
             return '', 0, 0
 
-        text_contents = ti.getText(0, self._script.getTextEndOffset(ti))
+        text_contents = ti.getText(0, ti.characterCount)
         line_offsets = []
         start_offset = 0
         while True:
@@ -2260,30 +2210,6 @@ class Utilities:
 
         return line
 
-    def _pronunciationForSegment(self, segment):
-        """Adjust the word segment to potentially replace it with what
-        those words actually sound like. Two pronunciation dictionaries
-        are checked. First the application specific one (which might be
-        empty), then the default (global) one.
-
-        Arguments:
-        - segment: the string to adjust for words in the pronunciation
-          dictionaries.
-
-        Returns: a new word segment adjusted for words found in the
-        pronunciation dictionaries, or the original word segment if there
-        was no dictionary entry.
-        """
-
-        from . import pronunciation_dict
-
-        newSegment = pronunciation_dict.getPronunciation(
-            segment, self._script.app_pronunciation_dict)
-        if newSegment == segment:
-            newSegment = pronunciation_dict.getPronunciation(segment)
-
-        return newSegment
-
     def adjustForLinks(self, obj, line, startOffset):
         """Adjust line to include the word "link" after any hypertext links.
 
@@ -2337,6 +2263,10 @@ class Utilities:
 
         return "".join(adjustedLine)
 
+    @staticmethod
+    def _processMultiCaseString(string):
+        return re.sub(r'(?<=[a-z])(?=[A-Z])', ' ', string)
+
     def adjustForPronunciation(self, line):
         """Adjust the line to replace words in the pronunciation dictionary,
         with what those words actually sound like.
@@ -2348,9 +2278,18 @@ class Utilities:
         dictionary.
         """
 
+        if settings.speakMultiCaseStringsAsWords:
+            line = self._processMultiCaseString(line)
+
+        if not settings.usePronunciationDictionary:
+            return line
+
         newLine = ""
         words = self.WORDS_RE.split(line)
-        newLine = ''.join(map(self._pronunciationForSegment, words))
+        newLine = ''.join(map(pronunciation_dict.getPronunciation, words))
+
+        if settings.speakMultiCaseStringsAsWords:
+            newLine = self._processMultiCaseString(newLine)
 
         return newLine
 
@@ -2497,7 +2436,7 @@ class Utilities:
                or character == self._script.NO_BREAK_SPACE_CHARACTER
 
     @staticmethod
-    def isVisibleRegion(ax, ay, awidth, aheight, bx, by, bwidth, bheight):
+    def containsRegion(ax, ay, awidth, aheight, bx, by, bwidth, bheight):
         """Returns true if any portion of region 'a' is in region 'b'"""
 
         highestBottom = min(ay + aheight, by + bheight)
@@ -2771,3 +2710,13 @@ class Utilities:
     def focusedChild(self, obj):
         isFocused = lambda x: x and x.getState().contains(pyatspi.STATE_FOCUSED)
         return pyatspi.findDescendant(obj, isFocused)
+
+    def _isNonModalPopOver(self, obj):
+        return False
+
+    def rgbFromString(self, attributeValue):
+        regex = re.compile("rgb|[^\w,]", re.IGNORECASE)
+        string = re.sub(regex, "", attributeValue)
+        red, green, blue = string.split(",")
+
+        return int(red), int(green), int(blue)
