@@ -26,6 +26,7 @@ __copyright__ = "Copyright (c) 2013-2014 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
+import re
 
 import orca.script_utilities as script_utilities
 
@@ -74,16 +75,19 @@ class Utilities(script_utilities.Utilities):
         except:
             return False
 
-        if state.contains(pyatspi.STATE_MODAL):
-            return False
-
-        try:
-            relations = obj.getRelationSet()
-        except:
+        if obj.getState().contains(pyatspi.STATE_MODAL):
             return False
 
+        relations = obj.getRelationSet()
         for relation in relations:
             if relation.getRelationType() == pyatspi.RELATION_POPUP_FOR:
                 return True
 
         return False
+
+    def rgbFromString(self, attributeValue):
+        regex = re.compile("rgb|[^\w,]", re.IGNORECASE)
+        string = re.sub(regex, "", attributeValue)
+        red, green, blue = string.split(",")
+
+        return int(red) >> 8, int(green) >> 8, int(blue) >> 8
